==> 0.3.0.tar.gz: lib/src/slot.dart <==
// ******************************************************************************
// Spine Runtimes Software License v2.5
//
// Copyright (c) 2013-2016, Esoteric Software
// All rights reserved.
//
// You are granted a perpetual, non-exclusive, non-sublicensable, and
// non-transferable license to use, install, execute, and perform the Spine
// Runtimes software and derivative works solely for personal or internal
// use. Without the written permission of Esoteric Software (see Section 2 of
// the Spine Software License Agreement), you may not (a) modify, translate,
// adapt, or develop new applications using the Spine Runtimes or otherwise
// create derivative works or improvements of the Spine Runtimes or (b) remove,
// delete, alter, or obscure any trademarks or any copyright, trademark, patent,
// or other intellectual property or proprietary rights notices on or in the
// Software, including any copy thereof. Redistributions in binary or source
// form must include this license and terms.
//
// THIS SOFTWARE IS PROVIDED BY ESOTERIC SOFTWARE "AS IS" AND ANY EXPRESS OR
// IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
// MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
// EVENT SHALL ESOTERIC SOFTWARE BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
// PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES, BUSINESS INTERRUPTION, OR LOSS OF
// USE, DATA, OR PROFITS) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
// IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
// POSSIBILITY OF SUCH DAMAGE.
// ******************************************************************************

part of spine_core;

class Slot {
  final SlotData data;
  final Bone bone;
  final Color color = Color();
  final Color? darkColor;
  Float32List attachmentVertices = Float32List(0);
  Attachment? attachment;
  late double attachmentTime;

  Slot(this.data, this.bone)
      : darkColor = data.darkColor == null ? null : Color() {
    setToSetupPose();
  }

  factory Slot.empty() => Slot(SlotData.empty(), Bone.empty());

  void setAttachment(Attachment? attachment) {
    if (this.attachment == attachment) return;
    this.attachment = attachment;
    attachmentTime = bone.skeleton.time;
    attachmentVertices = Float32List(0);
  }

  Attachment? getAttachment() => attachment;

  void setAttachmentTime(double time) {
    attachmentTime = bone.skeleton.time - time;
  }

  double getAttachmentTime() => bone.skeleton.time - attachmentTime;

  void setToSetupPose() {
    color.setFromColor(data.color);
    if (darkColor != null) darkColor!.setFromColor(data.darkColor!);
    if (data.attachmentName == null)
      attachment = null;
    else {
      attachment = null;
      setAttachment(
          bone.skeleton.getAttachment(data.index, data.attachmentName));
    }
  }
}

==> 0.3.1.tar.gz: lib/src/slot.dart <==
// ******************************************************************************
// Spine Runtimes Software License v2.5
//
// Copyright (c) 2013-2016, Esoteric Software
// All rights reserved.
//
// You are granted a perpetual, non-exclusive, non-sublicensable, and
// non-transferable license to use, install, execute, and perform the Spine
// Runtimes software and derivative works solely for personal or internal
// use. Without the written permission of Esoteric Software (see Section 2 of
// the Spine Software License Agreement), you may not (a) modify, translate,
// adapt, or develop new applications using the Spine Runtimes or otherwise
// create derivative works or improvements of the Spine Runtimes or (b) remove,
// delete, alter, or obscure any trademarks or any copyright, trademark, patent,
// or other intellectual property or proprietary rights notices on or in the
// Software, including any copy thereof. Redistributions in binary or source
// form must include this license and terms.
//
// THIS SOFTWARE IS PROVIDED BY ESOTERIC SOFTWARE "AS IS" AND ANY EXPRESS OR
// IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
// MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
// EVENT SHALL ESOTERIC SOFTWARE BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
// PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES, BUSINESS INTERRUPTION, OR LOSS OF
// USE, DATA, OR PROFITS) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
// IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
// POSSIBILITY OF SUCH DAMAGE.
// ******************************************************************************

part of spine_core;

class Slot {
  final SlotData data;
  final Bone bone;
  final Color color = Color();
  final Color? darkColor;
  Float32List attachmentVertices = Float32List(0);
  Attachment? attachment;
  late double attachmentTime;

  Slot(this.data, this.bone)
      : darkColor = data.darkColor == null ? null : Color() {
    setToSetupPose();
  }

  factory Slot.empty() => Slot(SlotData.empty(), Bone.empty());

  void setAttachment(Attachment? attachment) {
    if (this.attachment == attachment) return;
    this.attachment = attachment;
    attachmentTime = bone.skeleton.time;
    attachmentVertices = Float32List(0);
  }

  Attachment? getAttachment() => attachment;

  void setAttachmentTime(double time) {
    attachmentTime = bone.skeleton.time - time;
  }

  double getAttachmentTime() => bone.skeleton.time - attachmentTime;

  void setToSetupPose() {
    color.setFromColor(data.color);
    if (darkColor != null) darkColor!.setFromColor(data.darkColor!);
    if (data.attachmentName == null)
      attachment = null;
    else {
      attachment = null;
      setAttachment(
          bone.skeleton.getAttachment(data.index, data.attachmentName!));
    }
  }
}
